@@ -2,24 +2,24 @@ package Baseobject;
 
 use strict ;
 use Cwd;
-use Carp qw (cluck carp);
+use Carp qw(cluck carp);
 our @CARP_NOT;
 use Data::Dumper;
-require      Exporter;
-our @ISA = qw (Exporter);
-our @EXPORT = qw (baseconfigure verbosity freezeverbosity dumper);
+require Exporter;
+our @ISA = qw(Exporter);
+our @EXPORT = qw(baseconfigure verbosity freezeverbosity dumper);
 
-our $VERSION = "1.27";
+our $VERSION = "1.28";
 
-$Baseobject::directfeedback=0; # for downward compatibility
-$Baseobject::quickdeath=0;
-$Baseobject::verbosity=1;
+$Baseobject::directfeedback = 0; # for downward compatibility
+$Baseobject::quickdeath = 0;
+$Baseobject::verbosity = 1;
 
 
 sub new {
 	my $pkg = shift;
 	my $param = shift;
-	my $self = bless {},$pkg;
+	my $self = bless {}, $pkg;
 
 	$self->{LOCALSTATEDIR}= '';
 	$self->{SYSCONFDIR}   = '';
@@ -222,6 +222,7 @@ sub checkneeds {
 }
 
 sub inspect {
+	my $self = shift;
 	my $string = Dumper(@_);
 	my ($package, $file, $line) = caller();
 	$string .= " Inspect called at: $file line $line\n";
@@ -707,7 +708,7 @@ Note: be sure not to provide al list, but a REF to a list!.
 SEE ALSO:
     needs()
 
-=back 2
+=back
 
 =head2 checkneeds ()
 
@@ -719,7 +720,7 @@ Checks wether the requisted needs(), where all fulfilled.
 SEE ALSO:
     needs()
 
-=back 2
+=back
 
 =head2 clearerror ()
 
@@ -732,7 +733,7 @@ SEE ALSO:
     error() stderror()
 
 
-=back 2
+=back
 
 =head2 error ()
 
@@ -753,7 +754,7 @@ The verbosity() level can be changed to your liking from 0 (silent) to 3 (very v
 The errormessages accumulate until the status is cleared with clearerror().
 
 
-=back 2
+=back
 
 =head2 field ()
 
@@ -859,7 +860,7 @@ Is the current program a CGI script?
 
 Quit disgusting I know. I hope to improve it one day..
 
-=back 2
+=back
 
 =head2 needs ()
 
@@ -873,7 +874,7 @@ SYNOPSIS:
 SEE ALSO:
     allows() checkneeds()
 
-=back 2
+=back
 
 =head2 new ()
 
@@ -911,7 +912,7 @@ PARAMETERS:
 RETURNS:
     $self
 
-=back 2
+=back 
 
 =head2 quickdeath()
 
@@ -923,7 +924,7 @@ SYNOPSIS:
 SEE ALSO:
     error() verbosity()
 
-=back 2
+=back
 
 =head2 verbose ()
 
@@ -968,8 +969,7 @@ SYNOPSIS:
 
 =head1 BUGS
 
-Documentation is incomplete, obsolete, and sometimes wrrong, etc.
-One day all things will be better.
+Documentation is partially obsolete, and incomplete.
 
 =head1 AUTHOR
 
